/*
 * @Description: 产品工艺路线相关
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-06-21 15:34:28
 */

import { ActionItem } from "/@/components/Table";

/**
 * @description: 获取树形图标
 * @param {Recordable} params
 * @return {*}
 */
export function prodRouteCreateIcon(params: Recordable<any>) {
  let icon = '';
  switch (params['type']) {
    case 'Product':
      icon = 'similar-product|svg';
      break;
    case 'Route':
      icon = 'route|svg';
      break;
    case 'Node':
      icon = 'node|svg';
      break;
    case 'Action':
      icon = 'rot_action|svg';
      break;
    case 'Customer':
      icon = 'customer|svg';
      break;
  }
  return icon;
}

/**
 * @description: 产品绑定工艺路线操作字段自定义按钮
 * @return {*}
 */
export const prodRotActionItem: ActionItem[] = [
  {
    icon: 'binding|svg',
    tooltip: '绑定工艺',
    onClick:  () => { },
  },
];

/**
   * @description: 跳转产品工艺绑定页面
   * @param {*} record
   * @return {*}
   */
export function handleBinding(go: Fn, record: Recordable) {
  const id = {
    ID: record.ID,
    Name: 'ProdRouteBinding',
    CODE: record.ITEM_CODE,
    Title: `产品[${record.ITEM_CODE}]工艺绑定`,
    colSlots: [],
    crudColSlots: [],
    dense: true,
    pageTitle: `产品工艺绑定`,
    pageContent: `这里是管理产品的工艺绑定，一个产品可以绑定多个工艺路线`,
  };
  go(`/ProdRouteBinding/CP/${encodeURI(JSON.stringify(id))}`);
  // let obj = JSON.stringify(id);
  // push({
  //   path: '/ProdRouteBinding',
  //   state: {obj}, //HTML5 History API 的传参，参数隐藏不在地址栏显示（history）
  // })
}
